@@ -17,11 +17,18 @@
 -- along with this program.  If not, see <http://www.gnu.org/licenses/>.
 --
 
--- KEW data for Proposal Development Person Certification Questionnaire
-
 
 
 INSERT INTO KRNS_DOC_HDR_T (DOC_HDR_ID,VER_NBR,FDOC_DESC,ORG_DOC_HDR_ID,TMPL_DOC_HDR_ID,EXPLANATION,OBJ_ID) 
-  VALUES (10179,6,'Proposal Person Preloaded Questionnaire',null,null,null,SYS_GUID());
+  VALUES (10138,6,'Grants.gov Preloaded Questionnaire 2',null,null,null,SYS_GUID());
+
+INSERT INTO KRNS_DOC_HDR_T (DOC_HDR_ID,VER_NBR,FDOC_DESC,ORG_DOC_HDR_ID,TMPL_DOC_HDR_ID,EXPLANATION,OBJ_ID) 
+  VALUES (10139,6,'Grants.gov Preloaded Questionnaire 1',null,null,null,SYS_GUID());
+
+INSERT INTO KRNS_DOC_HDR_T (DOC_HDR_ID,VER_NBR,FDOC_DESC,ORG_DOC_HDR_ID,TMPL_DOC_HDR_ID,EXPLANATION,OBJ_ID) 
+  VALUES (10140,6,'Grants.gov Preloaded Questionnaire 3',null,null,null,SYS_GUID());
+
+INSERT INTO KRNS_DOC_HDR_T (DOC_HDR_ID,VER_NBR,FDOC_DESC,ORG_DOC_HDR_ID,TMPL_DOC_HDR_ID,EXPLANATION,OBJ_ID) 
+  VALUES (10146,6,'Grants.gov Preloaded Questionnaire 4',null,null,null,SYS_GUID());
 
 COMMIT;
