@@ -17,5 +17,6 @@
 -- along with this program.  If not, see <http://www.gnu.org/licenses/>.
 --
 
--- Create a new table for holding attachment content which can be used in place of storing them on the filesystem
-CREATE TABLE krns_att_cntnt_t (att_id VARCHAR2(36), att_cntnt BLOB);
+
+-- KULRICE-7237: KRNS_NTE_T is selected by a field with no indexes - full table scan every time
+create index KRNS_NTE_TI1 on KRNS_NTE_T (RMT_OBJ_ID);
