@@ -17,5 +17,5 @@
 -- along with this program.  If not, see <http://www.gnu.org/licenses/>.
 --
 
-UPDATE KREW_DOC_TYP_T SET LBL = 'Undefined' WHERE LBL is null;
-ALTER TABLE KREW_DOC_TYP_T MODIFY (LBL NOT NULL);
+ALTER TABLE KRIM_PND_GRP_ATTR_DATA_T ADD (ACTV_IND VARCHAR2(1) default 'Y'
+                                        , EDIT_FLAG VARCHAR2(1) default 'N');
